@@ -66,25 +66,3 @@ def test_date_range():
     assert len(lst) == 30
     end = lst[-1]
     assert end.year == 2020 and end.month==3 and end.day == 1
-
-
-def test_load_bow():
-    from text_models.utils import load_bow
-    bow = load_bow(lang='en')
-    repr = bow['hi']
-    assert len(repr) == 7
-
-
-def test_load_emoji():
-    from text_models.utils import load_emoji, load_bow
-    bow = load_bow(lang='en')
-    emo = load_emoji(lang='en', emoji=0)
-    X = bow.transform(['this is funny'])
-    output = emo.decision_function(X)    
-    assert np.all(output > 0.9)
-
-
-def test_emoji_information():
-    from text_models.utils import emoji_information
-    info = emoji_information()
-    assert info['💧']['number'] == 3905
