@@ -171,94 +171,6 @@ def download_tokens(day, lang:str= "Es", country: str='nogeo',
       raise Exception(path)
     return fname
 
-
-def load_bow(lang='es'):
-    """
-    Download and load the Bag of Word text representation
-
-    :param lang: ['ar', 'zh', 'en', 'fr', 'pt', 'ru', 'es']
-    :type lang: str
-    >>> from text_models.utils import load_bow
-    >>> bow = load_bow(lang='en')
-    >>> repr = bow['hi']
-    """
-    lang = lang.lower().strip()
-    assert lang in ['ar', 'zh', 'en', 'fr', 'pt', 'ru', 'es']
-    diroutput = join(dirname(__file__), 'models')
-    if not isdir(diroutput):
-        os.mkdir(diroutput)
-    fname = join(diroutput, f'{lang}_{MICROTC}.microtc')
-    if not isfile(fname):
-        path = f'https://github.com/INGEOTEC/text_models/releases/download/models/{lang}_{MICROTC}.microtc'
-        try:
-            request.urlretrieve(path, fname)
-        except HTTPError:
-            raise Exception(path)    
-    return load_model(fname)
-
-
-def load_emoji(lang='es', emoji=0):
-    """
-    Download and load the Emoji representation
-
-    :param lang: ['ar', 'zh', 'en', 'fr', 'pt', 'ru', 'es']
-    :type lang: str
-    :param emoji: emoji identifier
-    :type emoji: int
-
-    >>> from text_models.utils import load_emoji, load_bow
-    >>> bow = load_bow(lang='en')
-    >>> emo = load_emoji(lang='en', emoji=0)
-    >>> X = bow.transform(['this is funny'])
-    >>> df = emo.decision_function(X)
-    """
-    lang = lang.lower().strip()
-    assert lang in ['ar', 'zh', 'en', 'fr', 'pt', 'ru', 'es']
-    diroutput = join(dirname(__file__), 'models')
-    if not isdir(diroutput):
-        os.mkdir(diroutput)
-    fname = join(diroutput, f'{lang}_emo_{emoji}_muTC{MICROTC}.LinearSVC')
-    if not isfile(fname):
-        path = f'https://github.com/INGEOTEC/text_models/releases/download/models/{lang}_emo_{emoji}_muTC{MICROTC}.LinearSVC'
-        try:
-            request.urlretrieve(path, fname)
-        except HTTPError:
-            raise Exception(path)    
-    return load_model(fname)
-
-
-def emoji_information(lang='es'):
-    """
-    Download and load the Emoji statistics
-
-    :param lang: ['ar', 'zh', 'en', 'fr', 'pt', 'ru', 'es']
-    :type lang: str
-
-    >>> from text_models.utils import emoji_information
-    >>> info = emoji_information()
-    >>> info['💧']
-    {'recall': 0.10575916230366492, 'ratio': 0.0003977123419509893, 'number': 3905}
-    """
-    lang = lang.lower().strip()
-    assert lang in ['ar', 'zh', 'en', 'fr', 'pt', 'ru', 'es']
-    diroutput = join(dirname(__file__), 'models')
-    if not isdir(diroutput):
-        os.mkdir(diroutput)
-    data = []
-    for ext in ['info', 'perf']:
-        fname = join(diroutput, f'{lang}_emo.{ext}')
-        if not isfile(fname):
-            path = f'https://github.com/INGEOTEC/text_models/releases/download/models/{lang}_emo.{ext}'
-            try:
-                request.urlretrieve(path, fname)
-            except HTTPError:
-                raise Exception(path)    
-        data.append(load_model(fname))
-    uno, dos = data
-    [v.update(dict(number=uno[k])) for k, v in dos.items()]
-    return dos
-    
-
 class Gaussian(object):
     """
     Gaussian distribution
